Module git

Module git 

This module handles git operations.

Functions

get_git_diff
Generates a git diff for the repository at the provided path.
get_git_diff_between_branches
Generates a git diff between two branches for the repository at the provided path
get_git_log
Retrieves the git log between two branches for the repository at the provided path