This module provides sorting methods for files and directory trees.
Enums
Functions
- sort_
files - Sorts the provided
filesin place using the specifiedsort_method. - sort_
tree - Recursively sorts a directory tree (represented by
termtree::Tree<D>) in place using the specifiedFileSortMethod. For directory nodes, since modification time is typically unavailable, this function falls back to sorting by name. In effect, DateAsc is treated as NameAsc and DateDesc as NameDesc for directories.