This module handles git operations.
Functions
- get_
git_ diff - Generates a git diff for the repository at the provided path.
- get_
git_ diff_ between_ branches - Generates a git diff between two branches for the repository at the provided path
- get_
git_ log - Retrieves the git log between two branches for the repository at the provided path