Module sort

Module sort 

This module provides sorting methods for files and directory trees.

Enums

FileSortMethod

Functions

sort_files
Sorts the provided files in place using the specified sort_method.
sort_tree
Recursively sorts a directory tree (represented by termtree::Tree<D>) in place using the specified FileSortMethod. For directory nodes, since modification time is typically unavailable, this function falls back to sorting by name. In effect, DateAsc is treated as NameAsc and DateDesc as NameDesc for directories.